Package: nativeORT
Type: Package
Title: Native R 'ONNX' Runtime
Version: 1.0.1
Authors@R: c(
    person(
      "Caleb", "Carr",
      email = "calebmcarr1@gmail.com",
      role = c("aut", "cre")
    )
  )
Description: Provides R native 'ONNX' model inference without requiring 'Python', 'reticulate' bindings, or 'TensorFlow'. This package directly binds the 'ONNX Runtime' C API via 'Rcpp', enabling real-time inference for '.onnx' engines, all within R. Standard CPU execution is supported as well as the 'CoreML' Execution Provider (CEP) for Apple Silicon, all without external bindings. This package handles OS detection, linking 'ONNX' libraries, and inference. For more information about 'ONNX Runtime' see <https://onnxruntime.ai/>.
License: MIT + file LICENSE
Language: en-US
Encoding: UTF-8
LinkingTo: Rcpp
Imports: Rcpp, digest, glue
Config/roxygen2/version: 8.0.0
SystemRequirements: libonnxruntime (>= 1.20)
Suggests: ggplot2, knitr, rmarkdown
VignetteBuilder: knitr
URL: https://github.com/calebmcarr/nativeORT
BugReports: https://github.com/calebmcarr/nativeORT/issues
NeedsCompilation: yes
Packaged: 2026-05-17 15:14:40 UTC; calebcarr
Author: Caleb Carr [aut, cre]
Maintainer: Caleb Carr <calebmcarr1@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-17 22:40:11 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-05-18 00:55:49 UTC; unix
Archs: nativeORT.so.dSYM

# Generated by roxygen2: do not edit by hand

S3method(print,ort_session)
export(ort_binary_url)
export(ort_codesign)
export(ort_detect_os)
export(ort_download)
export(ort_infer_raw)
export(ort_install)
export(ort_install_dir)
export(ort_is_installed)
export(ort_session)
importFrom(Rcpp,sourceCpp)
useDynLib(nativeORT, .registration = TRUE)

# nativeORT

[![CRAN status](https://www.r-pkg.org/badges/version/nativeORT)](https://CRAN.R-project.org/package=nativeORT)

---

**Native ONNX Runtime inference for R, no Python required.**

nativeORT is the only R-native ONNX inference engine with no Python/reticulate dependencies. 
Built on direct C++ bindings to the onnxruntime C API, inference runs entirely within R.

nativeORT can run at real-time speeds, and Apple Silicon users can access the CoreML Execution
Provider. To the author's best research, this is the first R package with direct CoreML access
which does not rely on reticulate or python bridging.

---

## Why nativeORT?

The existing R interface for ONNX Runtime routes through Python/reticulate with Tensorflow
backends in Python. Bridging, non-R dependencies, and a large footprint make this a non-ideal
solution. As of publication, the existing packaging has not had a new release
since 2021. Additionally, the onnx-tensorflow dependency has not been actively maintained.
nativeORT exists to bridge this gap for AIML practitioners in R who want a modern,
R-native approach that runs fast without a large number of dependencies.

<p align="center">
  <img src="man/figures/comparison.svg" width="600"/>
</p>

## Installation

Now available through CRAN!

```
install.packages('nativeORT')
```

Or, if you prefer the latest release from Github:

```r
remotes::install_github("github.com/calebmcarr/nativeort")
```

nativeORT comes with a smart ONNX Runtime installer to detect your platform and install
the correct ORT 1.25.1 binary and verify the install. On first install:

```r
library(nativeORT)
ort_install()
library(nativeORT) # again, with ONNX libraries registered
```

After this, you can start inferencing on .onnx engines!

## Usage

### Creating an ORT Session

You'll need access to a .onnx file. Here's we'll use YOLOv11 nano from ultralytics as an
example.

```r
session <- nativeORT::ort_session(model_path)
```

### Inferencing

Now that you've created an ORT session (which handles all of the threading setup, etc.),
you can inference easily with standard R arrays.

```r
# typical RGB 256x256 image
input <- array(
  runif(1 * 3 * 256 * 256),
  dim=c(1L, 3L, 256L, 256L)
)

raw <- nativeORT::ort_infer_raw(session, input)
```

### CoreML Access

For users with Apple Silicon, nativeORT allows you to tap directly into the CoreML Execution
Provider, with dedicated hardware for more stable inferencing.

It's easy, only requiring a change in the session creation:

```r
// optional, explicitly creating cache dir helps speedup
dir.create(path.expand("~/.nativeORT/cache"),
           recursive = TRUE, showWarnings = FALSE
           )
session <- nativeORT::ort_session(model_path,
                                  provider='coreml',
                                  cache_dir=path.expand("~/.nativeORT/cache")
           )
```

### Benchmarks

nativeORT is fast, and supports real-time inferencing, opening up video streaming possibilities
without requiring Python.

Below is a benchmark on Apple M1 Silicon, targeting YOLOv11-nano on 50 consecutive 256x256 frames.
Tested with both the CPU and CoreML providers, we have a median inference time of 7-8 milliseconds, 
respectively (further discussion at [Benchmark Performance](vignettes/BenchmarkPerformance.Rmd)).


<p align="center">
  <img src="man/figures/benchmark.png" width="600"/>
</p>

And here are the control charts for latency. Both providers
are well within our threshold, even when accounting for a 3 sigma interval.Bene Nota: for this chart,
the warmup was excluded.

<p align="center">
  <img src="man/figures/control.png" width="600"/>
</p>

### AI Disclaimer

This code was written by me, and the logic human-made. The charts in this README were aided with the
help of AI tooling, however, as my eye for graphic design is not quite as keen.

### Author

Caleb Carr is an AI Engineer with an academic background in Applied Statistics.

## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

if (!nativeORT::ort_is_installed()) {
  knitr::opts_chunk$set(eval=FALSE)
}

## ----load,include=FALSE, eval = FALSE-----------------------------------------
# library(nativeORT)
# library(ggplot2)
# 
# model_path <- file.path(tools::R_user_dir("nativeORT", "data"), "yolo11n.onnx")
# 
# if (!file.exists(model_path)) {
#   message("Downloading YOLOv11 model (~12Mb)...")
#   dir.create(dirname(model_path), recursive=TRUE, showWarnings = FALSE)
#   utils::download.file(
#     url="https://github.com/ultralytics/assets/releases/download/v8.4.0/yolo11n.onnx",
#     destfile=model_path,
#     mode="wb"
#   )
#   message("yolo11n.onnx downloaded!")
# }

## ----benchmark, eval = FALSE--------------------------------------------------
# # typical RGB 256x256 image
# input <- array(
#   runif(1 * 3 * 256 * 256),
#   dim=c(1L, 3L, 256L, 256L)
# )
# 
# session <- nativeORT::ort_session(model_path,
#                                   threads=0L,
#                                   opt_level=99L)
# 
# times_cpu <- numeric(100)
# for (i in 1:100){
#   times_cpu[i] <- system.time(
#     nativeORT::ort_infer_raw(session, input)
#   )["elapsed"] * 1000
# }
# 
# # CoreML
# dir.create(path.expand("~/.nativeORT/cache"),
#            recursive = TRUE, showWarnings = FALSE
#            )
# session <- nativeORT::ort_session(model_path,
#                                   provider='coreml',
#                                   cache_dir=path.expand("~/.nativeORT/cache"),
#                                   threads=0L,
#                                   opt_level=99L
#            )
# 
# times_coreml <- numeric(100)
# for (i in 1:100){
#   times_coreml[i] <- system.time(
#     nativeORT::ort_infer_raw(session, input)
#   )["elapsed"] * 1000
# }

## ----plot, fig.width=7, eval = FALSE------------------------------------------
# results <- data.frame(
#   run=rep(1:length(times_cpu), 2),
#   provider=c(
#     rep("CPU (nativeORT)", length(times_cpu)),
#     rep("CoreML (nativeORT)", length(times_coreml))
#   ),
#   latency_ms=c(times_cpu, times_coreml)
# )
# 
# ggplot(results, aes(x=run, y=latency_ms, color=provider)) +
#   geom_line() +
#   geom_hline(yintercept=33.3, linetype="dashed", color="red") +
#   annotate("text", x=85, y=40, label="29.97 fps threshold") +
#   labs(
#     title="Inference Latency Across Inference Engines",
#     subtitle="YOLOv11n, 256x256 Images, Apple M1",
#     x="Run",
#     y="Latency (ms)"
#   ) +
#   theme_minimal()

#' ort_infer_raw
#'
#' @param session ORT session
#' @param input tensor to infer on
#'
#' @returns ORT output
#' @export
#'
#' @examples
#' \donttest{
#'   if (file.exists("model.onnx")) {
#'     session <- ort_session("model.onnx")
#'     input <- array(runif(1 * 3 * 256 * 256), dim = c(1L, 3L, 256L, 256L))
#'     ort_infer_raw(session, input)
#'   }
#' }
ort_infer_raw <- function(session, input){
  ort_run(
    session_ptr = session$ptr,
    input_array = as.numeric(input),
    input_shape = as.integer(dim(input)),
    input_name = session$input_names[1],
    output_name = session$output_names[1]
  )
}

.onAttach <- function(libname, pkgname) {
  if (!ort_is_installed()) {
    packageStartupMessage(
      "nativeORT: ONNX Runtime not found.\n",
      "  Run ort_install() to download it \n.",
      "  Then re-install nativeORT to enable inference."
    )
  }
}

.ort_version <- "1.25.1"
.ort_version_short <- "1.25"
.ort_checksums <- list(
  "osx-arm64" = "18987ec3187b5f29ba798109750f6135060560ad4e0a52678fcc753ee8fb3091",
  "linux-aarch64" = "daa71b56b00c4ab34798a3d96ca41a32ece4d3e302dc2386d3cca83fd4491214",
  "linux-x64" = "eb566a49cfc49ef0642f809b69340b5bb656c7c4905ba873526d226f2c005816",
  "win-x64" = "33f2e8a63774811f99a5fc224cac32f4eed8c27643d46c6cc685319fa8f18019"
)

#' ort_detect_os
#'
#' @returns str - platform
#' @export
#'
#' @examples ort_detect_os()
ort_detect_os <- function(){
  os_name <- Sys.info()[['sysname']]
  arch <- R.version$arch
  if (os_name == "Darwin"){
    # apple silicon vs x86
    if (grepl("aarch64|arm64", arch)) return ("osx-arm64")
    else return('osx-arm64')
  } else if (os_name == "Linux") {
    if (grepl("aarch64|arm64", arch)) return("linux-aarch64")
    else return("linux-x64")
  } else if (os_name == "Windows") {
    return("win-x64")
  } else {
    stop("Unsupported platform")
  }
}

#' ort_install_dir
#'
#' @returns where the install lives
#' @export
#'
#' @examples ort_install_dir()
ort_install_dir <- function(){
  tools::R_user_dir("nativeORT", which="data")
}

#' ort_binary_url
#'
#' @returns string where to download onnxruntime from
#' @export
#'
#' @examples ort_binary_url()
ort_binary_url <- function(){
  os <- ort_detect_os()
  base <- "https://github.com/microsoft/onnxruntime/releases/download"
  glue::glue("{base}/v{.ort_version}/onnxruntime-{os}-{.ort_version}.tgz")
}

#' ort_is_installed
#'
#' @returns boolean for if you have onnx runtime or not
#' @export
#'
#' @examples ort_is_installed()
ort_is_installed <- function(){
  lib_file <- switch(ort_detect_os(),
                     "osx-arm64" = "libonnxruntime.dylib",
                     "osx-x86_64" = "libonnxruntime.dylib",
                     "linux-x64"    = "libonnxruntime.so",
                     "linux-aarch64"= "libonnxruntime.so",
                     "win-x64"      = "onnxruntime.dll"
              )
  lib <- file.path(ort_install_dir(), "lib", lib_file)
  file.exists(lib)
}

#' ort_codesign
#'
#' for macs, signs the downloaded binaries
#'
#' @param lib_dir where the libraries are
#'
#' @returns invisible lib path
#' @export
#'
#' @examples
#' \donttest{
#'   if(!ort_is_installed()){
#'     ort_codesign(file.path(ort_install_dir(), "lib"))
#'   }
#' }
ort_codesign <- function(lib_dir) {
  dylibs <- list.files(
    lib_dir,
    pattern = "\\.dylib$",
    full.names = TRUE
  )

  if (length(dylibs) == 0){
    warning("No .dylib files found!")
  }

  message("Signing libraries (macOS)...")
  for (lib in dylibs) {
    system2("xattr", c("-dr", "com.apple.quarantine", shQuote(lib)))
    system2("codesign", c("--force", "--deep", "--sign", "-", shQuote(lib)))
  }

  invisible(lib_dir)
}

#' ort_download
#'
#' @param url where to download from
#' @param dest_dir where to download to
#'
#' @returns invisible dest_dir
#' @export
#'
#' @examples
#' \donttest{
#' if (!ort_is_installed()){
#'   ort_download(ort_binary_url(), ort_install_dir())}
#' }
ort_download <- function(url, dest_dir) {
  # download
  dir.create(dest_dir, recursive = TRUE, showWarnings= FALSE)
  tgz_path <- file.path(dest_dir, basename(url))

  message("Downloading ONNX Runtime ", .ort_version, "...")
  utils::download.file(url, tgz_path, mode='wb')

  #verify checksum
  message("Verifying download...")
  os <- ort_detect_os()
  expected_sum <- .ort_checksums[[os]]
  received_sum <- digest::digest(tgz_path, algo="sha256", file=TRUE)

  # if it fails
  if (!identical(expected_sum, received_sum)) {
    unlink(tgz_path)
    stop(
      "Checksum mismatch! Download my be corrupt, try again!"
    )
  }

  # now extract
  message("Checksum verified!")
  message("Extracting...")

  utils::untar(tgz_path, exdir=dest_dir)
  unlink(tgz_path)

  invisible(dest_dir)
}

#' ort_install
#'
#' @returns invisible where it was saved to
#' @export
#'
#' @examples
#' \donttest{
#'   if(!ort_is_installed()){
#'     ort_install()}
#'   }
ort_install <- function() {
  # prevent re-installation
  if (ort_is_installed()) {
    message("onnxruntime ", .ort_version, " is already installed.")
    return(invisible(ort_install_dir()))
  }

  # orchestrate download
  os <- ort_detect_os()
  url <- ort_binary_url()
  dest <- ort_install_dir()

  ort_download(url, dest)

  extracted <- file.path(dest, paste0("onnxruntime-", os, "-", .ort_version))
  file.copy(file.path(extracted, "include"), dest, recursive = TRUE)
  file.copy(file.path(extracted, "lib"), dest, recursive = TRUE)
  unlink(extracted, recursive = TRUE)

  # handle macOS signatures if needed
  if (os == 'osx-arm64') {
    ort_codesign(file.path(dest, "lib"))
  }

  message("onnxruntime ", .ort_version, " installed successfully!")
  message("location: ", dest)
  invisible(dest)

}

# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

ort_run <- function(session_ptr, input_array, input_shape, input_name, output_name) {
    .Call(`_nativeORT_ort_run`, session_ptr, input_array, input_shape, input_name, output_name)
}

ort_version <- function() {
    .Call(`_nativeORT_ort_version`)
}

ort_create_env <- function() {
    .Call(`_nativeORT_ort_create_env`)
}

ort_create_session <- function(env_ptr, model_path, provider = "cpu", cache_dir = "", threads = 0L, opt_level = 99L) {
    .Call(`_nativeORT_ort_create_session`, env_ptr, model_path, provider, cache_dir, threads, opt_level)
}

ort_session_input_count <- function(session_ptr) {
    .Call(`_nativeORT_ort_session_input_count`, session_ptr)
}

ort_session_output_count <- function(session_ptr) {
    .Call(`_nativeORT_ort_session_output_count`, session_ptr)
}

ort_session_input_names <- function(session_ptr) {
    .Call(`_nativeORT_ort_session_input_names`, session_ptr)
}

ort_session_output_names <- function(session_ptr) {
    .Call(`_nativeORT_ort_session_output_names`, session_ptr)
}

#' session.R
#'
#' @param path where the .onnx is located
#' @param type detection/classificaton/segmentation
#' @param provider cpu or coreml (only for apple silicon)
#' @param cache_dir where coreml cache be directed
#' @param threads =  0 for all, integer otherwise
#' @param opt_level = 99 for all ops, 1 for basics
#'
#' @returns ORT session object
#' @export
#'
#' @examples
#' \donttest{
#'   if (file.exists('./yolov11n.onnx')) {
#'     ort_session('./yolov11n.onnx', 'detection')
#'   }
#' }
ort_session <- function(path,
                        type='detection',
                        provider="cpu",
                        cache_dir=NULL,
                        threads=0L,
                        opt_level=99L) {
  # file verifications
  if (!file.exists(path)) {
    stop("Model file not found")
  }
  if (!grepl("\\.onnx$", path, ignore.case = TRUE)) {
    stop("File must be an .onnx model")
  }
  if (provider == "coreml" && .Platform$OS.type != "unix") {
    warning("CoreML is only available on macOS, falling back to CPU")
    provider <- "cpu"
  }
  cache <- if (!is.null(cache_dir)) {
    normalizePath(cache_dir, mustWork = FALSE)
  } else {
    ""
  }


  env <- ort_create_env()
  sess <- ort_create_session(env_ptr=env,
                             model_path=normalizePath(path),
                             provider=provider,
                             cache_dir=cache,
                             threads=as.integer(threads),
                             opt_level=as.integer(opt_level)
          )

  structure(
    list(
      ptr=sess,
      env=env,
      path=path,
      type=type,
      provider=provider,
      threads=as.integer(threads),
      opt_level=as.integer(opt_level),
      input_names=ort_session_input_names(sess),
      output_names=ort_session_output_names(sess),
      n_inputs=ort_session_input_count(sess),
      n_outputs=ort_session_output_count(sess)
    ),
    class="ort_session"
  )
}


#' print.ort_session
#'
#' @param x session object
#' @param ... extra params
#'
#' @returns invisible session
#' @exportS3Method print ort_session
#'
#' @examples
#' \donttest{
#'   if (file.exists("model.onnx")) {
#'     session <- ort_session("model.onnx")
#'     print(session)
#'   }
#' }
print.ort_session <- function(x, ...) {
  cat("nativeORT session\n")
  cat("  model: ", x$path, "\n")
  cat(" threads", ifelse(x$threads == 0, "auto", x$threads), "\n")
  cat("  inputs: ", paste(x$input_names, collapse=", "), "\n")
  cat("  outputs: ", paste(x$output_names, collapse=", "), "\n")
  invisible(x)
}

---
title: "BenchmarkPerformance"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{BenchmarkPerformance}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
  %\VignetteDepends{nativeORT}
VignetteBuilder: knitr
---


```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

if (!nativeORT::ort_is_installed()) {
  knitr::opts_chunk$set(eval=FALSE)
}
```

```{r load,include=FALSE, eval = FALSE}
library(nativeORT)
library(ggplot2)

model_path <- file.path(tools::R_user_dir("nativeORT", "data"), "yolo11n.onnx")

if (!file.exists(model_path)) {
  message("Downloading YOLOv11 model (~12Mb)...")
  dir.create(dirname(model_path), recursive=TRUE, showWarnings = FALSE)
  utils::download.file(
    url="https://github.com/ultralytics/assets/releases/download/v8.4.0/yolo11n.onnx",
    destfile=model_path,
    mode="wb"
  )
  message("yolo11n.onnx downloaded!")
}
```

The purpose of this Vignette is to demonstrate the performance of onnxruntime inference with nativeORT, including CoreML capabilities. This will demonstrate nativeORT is capable of running at real-time (sub-29.97fps) inferencing.

This is tested on 50 256x256 arrays on an Apple M1 machine, simulating an incoming video stream.

## nativeORT CPU & CoreML

```{r benchmark, eval = FALSE}
# typical RGB 256x256 image
input <- array(
  runif(1 * 3 * 256 * 256),
  dim=c(1L, 3L, 256L, 256L)
)

session <- nativeORT::ort_session(model_path,
                                  threads=0L,
                                  opt_level=99L)

times_cpu <- numeric(100)
for (i in 1:100){
  times_cpu[i] <- system.time(
    nativeORT::ort_infer_raw(session, input)
  )["elapsed"] * 1000
}

# CoreML
dir.create(path.expand("~/.nativeORT/cache"),
           recursive = TRUE, showWarnings = FALSE
           )
session <- nativeORT::ort_session(model_path,
                                  provider='coreml',
                                  cache_dir=path.expand("~/.nativeORT/cache"),
                                  threads=0L,
                                  opt_level=99L
           )

times_coreml <- numeric(100)
for (i in 1:100){
  times_coreml[i] <- system.time(
    nativeORT::ort_infer_raw(session, input)
  )["elapsed"] * 1000
}
```

```{r plot, fig.width=7, eval = FALSE}
results <- data.frame(
  run=rep(1:length(times_cpu), 2),
  provider=c(
    rep("CPU (nativeORT)", length(times_cpu)),
    rep("CoreML (nativeORT)", length(times_coreml))
  ),
  latency_ms=c(times_cpu, times_coreml)
)

ggplot(results, aes(x=run, y=latency_ms, color=provider)) +
  geom_line() + 
  geom_hline(yintercept=33.3, linetype="dashed", color="red") +
  annotate("text", x=85, y=40, label="29.97 fps threshold") +
  labs(
    title="Inference Latency Across Inference Engines",
    subtitle="YOLOv11n, 256x256 Images, Apple M1",
    x="Run",
    y="Latency (ms)"
  ) +
  theme_minimal()
```

## Results

Notably, nativeORT can run substantially below real-time requirements. Due to optimization in the C++ bindings, the CPU and CoreML latency are near parity; however, it is of note that the CoreML runs offer better stability as they sit on dedicated hardware, whereas the CPU is subject to slowdowns when other processes hit.

CoreML does require a warmup (as noticed in the spike) but after one or two inferences, it becomes real-time performant. At a median latency of 7-8 milliseconds on Apple M1 Silicon, there is still time to run post-processing and remain under target latency.

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_download}
\alias{ort_download}
\title{ort_download}
\usage{
ort_download(url, dest_dir)
}
\arguments{
\item{url}{where to download from}

\item{dest_dir}{where to download to}
}
\value{
invisible dest_dir
}
\description{
ort_download
}
\examples{
\donttest{
if (!ort_is_installed()){
  ort_download(ort_binary_url(), ort_install_dir())}
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_codesign}
\alias{ort_codesign}
\title{ort_codesign}
\usage{
ort_codesign(lib_dir)
}
\arguments{
\item{lib_dir}{where the libraries are}
}
\value{
invisible lib path
}
\description{
for macs, signs the downloaded binaries
}
\examples{
\donttest{
  if(!ort_is_installed()){
    ort_codesign(file.path(ort_install_dir(), "lib"))
  }
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_binary_url}
\alias{ort_binary_url}
\title{ort_binary_url}
\usage{
ort_binary_url()
}
\value{
string where to download onnxruntime from
}
\description{
ort_binary_url
}
\examples{
ort_binary_url()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session.R
\name{ort_session}
\alias{ort_session}
\title{session.R}
\usage{
ort_session(
  path,
  type = "detection",
  provider = "cpu",
  cache_dir = NULL,
  threads = 0L,
  opt_level = 99L
)
}
\arguments{
\item{path}{where the .onnx is located}

\item{type}{detection/classificaton/segmentation}

\item{provider}{cpu or coreml (only for apple silicon)}

\item{cache_dir}{where coreml cache be directed}

\item{threads}{=  0 for all, integer otherwise}

\item{opt_level}{= 99 for all ops, 1 for basics}
}
\value{
ORT session object
}
\description{
session.R
}
\examples{
\donttest{
  if (file.exists('./yolov11n.onnx')) {
    ort_session('./yolov11n.onnx', 'detection')
  }
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_install_dir}
\alias{ort_install_dir}
\title{ort_install_dir}
\usage{
ort_install_dir()
}
\value{
where the install lives
}
\description{
ort_install_dir
}
\examples{
ort_install_dir()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/inference.R
\name{ort_infer_raw}
\alias{ort_infer_raw}
\title{ort_infer_raw}
\usage{
ort_infer_raw(session, input)
}
\arguments{
\item{session}{ORT session}

\item{input}{tensor to infer on}
}
\value{
ORT output
}
\description{
ort_infer_raw
}
\examples{
\donttest{
  if (file.exists("model.onnx")) {
    session <- ort_session("model.onnx")
    input <- array(runif(1 * 3 * 256 * 256), dim = c(1L, 3L, 256L, 256L))
    ort_infer_raw(session, input)
  }
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_detect_os}
\alias{ort_detect_os}
\title{ort_detect_os}
\usage{
ort_detect_os()
}
\value{
str - platform
}
\description{
ort_detect_os
}
\examples{
ort_detect_os()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session.R
\name{print.ort_session}
\alias{print.ort_session}
\title{print.ort_session}
\usage{
\method{print}{ort_session}(x, ...)
}
\arguments{
\item{x}{session object}

\item{...}{extra params}
}
\value{
invisible session
}
\description{
print.ort_session
}
\examples{
\donttest{
  if (file.exists("model.onnx")) {
    session <- ort_session("model.onnx")
    print(session)
  }
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_install}
\alias{ort_install}
\title{ort_install}
\usage{
ort_install()
}
\value{
invisible where it was saved to
}
\description{
ort_install
}
\examples{
\donttest{
  if(!ort_is_installed()){
    ort_install()}
  }
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/install.R
\name{ort_is_installed}
\alias{ort_is_installed}
\title{ort_is_installed}
\usage{
ort_is_installed()
}
\value{
boolean for if you have onnx runtime or not
}
\description{
ort_is_installed
}
\examples{
ort_is_installed()
}
